DailyItem_ADDONNAME = "DailyItems";
DailyItem_MACRONAME = "DailyItem";
DailyItem_VERSION = "2.0.1-20110210";

SLASH_DAILYITEM1, SLASH_DAILYITEM2 = '/dailyitem', '/di';
function SlashCmdList.DAILYITEM(msg)
  if (strlower(msg) == "zone") then
    DailyItem_Print("Zone = ["..GetRealZoneText().."]");
    DailyItem_Print("SubZone = ["..GetSubZoneText().."]");
  end
end

-- I want this to run when you log in, update bag contents, swap zones, or change targets.

function DailyItem_OnLoad(self)
  self:RegisterEvent("PLAYER_LOGIN");
  self:RegisterEvent("BAG_UPDATE");
  self:RegisterEvent("ZONE_CHANGED");
  self:RegisterEvent("PLAYER_TARGET_CHANGED");
end

function DailyItem_OnEvent(self, event)
  if (InCombatLockdown()) then return; end

  if (event == "PLAYER_LOGIN") then
    if (GetMacroIndexByName(DailyItem_MACRONAME) == 0) then
      local numGenMacros, numCharMacros = GetNumMacros();
      if (numGenMacros < 36) then
        CreateMacro(DailyItem_MACRONAME, 12, "", nil, nil)
      else
        DailyItem_Print("You have 36 General Macros. Cannot add "..DailyItem_MACRONAME.."!");
      end
    end
    DailyItem_MakeArrays();
    DIQuestsLength = table.getn(DailyItem_Quests);
    DINoQuestsLength= table.getn(DailyItem_NoQuests);
    DailyItem_Print("DailyItems Databese:\nQuests - "..DIQuestsLength.."\nNoQuests - "..DINoQuestsLength);
  end
  DailyItem_Go();
end

function DailyItem_Print(msg)
  if ((msg) and (strlen(msg) > 0)) then
    if (DEFAULT_CHAT_FRAME) then
      DEFAULT_CHAT_FRAME:AddMessage(msg, 1, 1, 0);
    end
  end
end

-- Line 50
function DailyItem_NumFromLink(itemLink)
  if (not itemLink) then
    return nil;
  end
  local _, _, itemNumber = strfind(itemLink, "item:(%d+):");
  return itemNumber;
end

function DailyItem_CheckZone(Zone)
  if (not Zone) or (Zone == GetRealZoneText()) then
    return true;
  else
    return false;
  end
end

function DailyItem_CheckSubZone(Zone)
  if (not Zone) or (Zone == GetSubZoneText()) then
    return true;
  else
    return false;
  end
end

function DailyItem_ItemInBags(itemID)
  for bagID = 0, 4, 1 do
    local bagSlotCnt = GetContainerNumSlots(bagID);
    if (bagSlotCnt > 0) then
      for slot = 1, bagSlotCnt, 1 do
        local itemLink = GetContainerItemLink(bagID, slot);
        local itemNumber = tonumber(DailyItem_NumFromLink(itemLink));
        if (itemNumber) and (itemID == itemNumber) then
          return true;
        end
      end
    end
  end
  return false;
end

function DailyItem_ItemWorn(itemID)
  for equipID = 0, 19, 1 do 
    local itemNumber = GetInventoryItemID("player",equipID);
    if (itemNumber) then 
      if (itemID == itemNumber) then
        return true;
      end
    end
  end
-- Line 100
  return false;
end

function DailyItem_Go()

  local macroText; 
  local numQuests = GetNumQuestLogEntries(); -- Get the number of quests in my quest log

  for questNo = 1, numQuests -- Now, cycle through each quest in the quest log
  do 
    local questTitle, level, questTag, suggestedGroup, isHeader, isCollapsed, isComplete, isDaily = GetQuestLogTitle(questNo); -- Get the information about each line in the quest log
    if (not isHeader) -- Dump the lines that are just headers rather than actual quests
    then
      local questID = tonumber(GetQuestLink(questNo):match("\124Hquest:(%d+):")); -- Get the actual quest ID
      for index = 1, DIQuestsLength -- Cycle through all quests in the database
      do 
        if ((isComplete) and (questID + DailyItem_Quests[index][6] == 0)) or ((not isComplete) and (questID == DailyItem_Quests[index][6])) -- Check if the current DB line matches the current quest
        then
          if DailyItem_CheckZone(DailyItem_Quests[index][1]) and DailyItem_CheckSubZone(DailyItem_Quests[index][2]) -- Check if we're in the right part of the world
          then
            if (DailyItem_Quests[index][3]) -- Check if there is an associated item to use
            then

              if DailyItem_ItemInBags(DailyItem_Quests[index][3]) -- Do we have it in our bags?
              then
                if (IsEquippableItem(DailyItem_Quests[index][3])) -- Right, we have the item.  Do we need to be wearing it?  If so, get on with it.
                then
                  macroText = "#showtooltip\n/equip item:"..DailyItem_Quests[index][3];
                else
                  if (not DailyItem_Quests[index][4]) or (DailyItem_Quests[index][4] == UnitName("target")) -- Targetting bit.  If we don't need a target or we already have the right target just use the item
                  then
                    macroText = "#showtooltip\n/use item:"..DailyItem_Quests[index][3];
                  elseif (DailyItem_Quests[index][5] ~= 0) -- If we need to target something and we're not yet targetting it, target it then use the item
                  then
                    macroText = "#showtooltip\n/target [noexists] "..DailyItem_Quests[index][4].."\n/use item:"..DailyItem_Quests[index][3];
                  end -- Targetting
                end -- Equip it or use it

              elseif DailyItem_ItemWorn(DailyItem_Quests[index][3]) -- OK, we've checked the bags, now check if we're wearing it.
              then
                if (not DailyItem_Quests[index][4]) or (DailyItem_Quests[index][4] == UnitName("target")) -- Targetting bit.  If we don't need a target or we already have the right target just use the item
                then
                  macroText = "#showtooltip\n/use item:"..DailyItem_Quests[index][3];
                elseif (DailyItem_Quests[index][5] ~= 0) -- If we need to target something and we're not yet targetting it, target it then use hte item
                then
                  macroText = "#showtooltip\n/target [noexists] "..DailyItem_LocalItems[index][4].."\n/use item:"..DailyItem_Quests[index][3];
                end -- Targetting

              end -- Check for item in bags or on character.

            else -- No, we don't have an associated item for this quest
              macroText = "/target [noexists] "..DailyItem_Quests[index][4]; -- So, there's no item for this quest.  Must mean we need to target something
            end -- Is there an item associated with quest
          end -- Zonecheck
        end -- match the current quest to database
      end -- Cycling through database items
    end -- Checking for header
  end -- Cycling through each quest in my log

  if (not macroText) -- If we;ve not matched a quest, go through the same process with non-quest based items
  then
    for index = 1, DINoQuestsLength -- Cycle through all non-quest entries in the database
    do 
      if DailyItem_CheckZone(DailyItem_NoQuests[index][1]) and DailyItem_CheckSubZone(DailyItem_NoQuests[index][2]) -- Check if we're in the right part of the world
      then
        if (DailyItem_NoQuests[index][3]) -- Check if there is an associated item to use
        then

          if DailyItem_ItemInBags(DailyItem_NoQuests[index][3]) -- Do we have it in our bags?
          then
            if (IsEquippableItem(DailyItem_NoQuests[index][3])) -- Right, we have the item.  Do we need to be wearing it?  If so, get on with it.
            then
              macroText = "#showtooltip\n/equip item:"..DailyItem_NoQuests[index][3];
            else
              if (not DailyItem_NoQuests[index][4]) or (DailyItem_NoQuests[index][4] == UnitName("target")) -- Targetting bit.  If we don't need a target or we already have the right target just use the item
              then
                macroText = "#showtooltip\n/use item:"..DailyItem_NoQuests[index][3];
              elseif (DailyItem_NoQuests[index][5] ~= 0) -- If we need to target something and we're not yet targetting it, target it then use the item
              then
                macroText = "#showtooltip\n/target [noexists] "..DailyItem_NoQuests[index][4].."\n/use item:"..DailyItem_NoQuests[index][3];
              end -- Targetting
            end -- Equip it or use it

          elseif DailyItem_ItemWorn(DailyItem_NoQuests[index][3]) -- OK, we've checked the bags, now check if we're wearing it.
          then
            if (not DailyItem_NoQuests[index][4]) or (DailyItem_NoQuests[index][4] == UnitName("target")) -- Targetting bit.  If we don't need a target or we already have the right target just use the item
            then
              macroText = "#showtooltip\n/use item:"..DailyItem_NoQuests[index][3];
            elseif (DailyItem_NoQuests[index][5] ~= 0) -- If we need to target something and we're not yet targetting it, target it then use hte item
            then
              macroText = "#showtooltip\n/target [noexists] "..DailyItem_NoQuests[index][4].."\n/use item:"..DailyItem_NoQuests[index][3];
            end -- Targetting

          end -- Check for item in bags or on character.

        else -- No, we don't have an associated item for this quest
          macroText = "/target [noexists] "..DailyItem_NoQuests[index][4]; -- So, there's no item for this quest.  Must mean we need to target something
        end -- Is there an item associated with quest
      end -- Zonecheck
    end -- Non-quest based DB entries
  end -- mactotext check

  if (macroText) -- So, we've decided what we want in our macro, so write it out (only if there's something to write)
  then
    EditMacro(DailyItem_MACRONAME, DailyItem_MACRONAME, 1, macroText, nil, nil);
  end -- Writing out macro

end -- End of the main function.
